@@ -1,7 +1,7 @@
 # route include
 # ~~~~~~~~~~~~~~
 
-import typing
+from typing import Callable, List
 
 from simple_starlette.app import SimpleStarlette
 
@@ -31,13 +31,26 @@ class Include:
         self.app = app
         if not prefix.startswith("/"):
             raise TypeError("prefix must startwith '/'")
-        self.prefix = prefix
+        self.prefix = prefix[:-1] if prefix.endswith("/") else prefix
 
-    def route(self, path: str, websoket_route: bool = False, **options):
+    def route(
+        self,
+        path: str,
+        allow_methods: List[str] = [],
+        websocket_route: bool = False,
+        **options,
+    ):
         if not path.startswith("/"):
             path = "/" + path
 
-        def register(cls: typing.Callable):
-            self.app.route(path, websoket_route=websoket_route, **options)(cls)
+        options["include_name"] = self.prefix
+
+        def register(cls: Callable):
+            self.app.route(
+                path=self.prefix + path,
+                websocket_route=websocket_route,
+                allow_methods=allow_methods,
+                **options,
+            )(cls)
 
         return register
